"""
VERSION: 2025-10-26
AUTHOR: ColorGradient Contributor(s), © 2025. All rights reserved.
LICENSE: Creative Commons Attribution-NonCommercial 4.0 (CC BY-NC 4.0)
"""

from .core import (
	plot_gradient_grid,
	draw_nested_grid_subplot,
	create_circular_gradient,
	create_color_map,
	validate_data_range,
	calculate_grid_layout,
	create_square_subplots,
	DEFAULT_COLOR_SCHEMA
)
__version__ = "1.1.0"
__all__ = [
	'plot_gradient_grid',
	'draw_nested_grid_subplot',
	'create_circular_gradient',
	'create_color_map',
	'validate_data_range',
	'calculate_grid_layout',
	'create_square_subplots',
	'DEFAULT_COLOR_SCHEMA'
]